==> nextcloud-30.0.13.tgz: nextcloud/apps/systemtags/l10n/sl.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Dodana je sistemska oznaka %1$s",
    "Added system tag {systemtag}" : "Dodana je sistemska oznaka {systemtag}",
    "Added system tag %1$s" : "Dodana je sistemska oznaka %1$s",
    "%1$s added system tag %2$s" : "Uporabnik %1$s doda sistemsko oznako %2$s",
    "{actor} added system tag {systemtag}" : "Uporabnik {actor} doda sistemsko oznako {systemtag}",
    "System tag %1$s removed by the system" : "Sistemska oznaka %1$s je odstranjena iz sistema",
    "Removed system tag {systemtag}" : "Odstranjena je sistemska oznaka {systemtag}",
    "Removed system tag %1$s" : "Odstranjena je sistemska oznaka %1$s",
    "%1$s removed system tag %2$s" : "%1$s odstrani sistemsko oznako %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstrani sistemsko oznako {systemtag}",
    "You created system tag %1$s" : "Ustvarite sistemsko oznako %1$s",
    "You created system tag {systemtag}" : "Ustvarite sistemsko oznako {systemtag}",
    "%1$s created system tag %2$s" : "Uporabnik %1$s je ustvaril sistemsko oznako %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ustvari sistemsko oznako {systemtag}",
    "You deleted system tag %1$s" : "Izbrišete sistemsko oznako %1$s",
    "You deleted system tag {systemtag}" : "Izbrišete sistemsko oznako {systemtag}",
    "%1$s deleted system tag %2$s" : "Uporabnik %1$s izbriše sistemsko oznako %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} izbriše sistemsko oznako {systemtag}",
    "You updated system tag %2$s to %1$s" : "Posodobili ste sistemsko oznako %2$s v %1$s.",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Posodobite sistemsko oznako {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s posodobi sistemsko oznako %3$s v %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} posodobi sistemsko oznako {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Sistem doda sistemsko oznako %2$s na datoteko %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Sistem doda sistemsko oznako {systemtag} na datoteko {file}",
    "You added system tag %2$s to %1$s" : "Datoteki %1$s dodate oznako %2$s.",
    "You added system tag {systemtag} to {file}" : "Datoteki {file} dodate sistemsko oznako {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s doda sistemsko oznako %3$s na datoteko %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} doda datoteki {file} sistemsko oznako {systemtag}",
    "System tag %2$s was removed from %1$s by the system" : "Sistem odstrani sistemsko oznako %2$s z datoteke %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Sistem odstrani sistemsko oznako {systemtag} z datoteke {file}",
    "You removed system tag %2$s from %1$s" : "Odstranili ste sistemsko oznako %2$s od %1$s",
    "You removed system tag {systemtag} from {file}" : "Odstranite sistemsko oznako {systemtag} z datoteke {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstrani sistemsko datoteko %3$s z datoteke %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstrani sistemsko oznako {systemtag} z datoteke {file}",
    "%s (restricted)" : "%s (omejeno)",
    "%s (invisible)" : "%s (nevidno)",
    "<strong>System tags</strong> for a file have been modified" : "Spremenjene so bile <strong>sistemske oznake</strong> datoteke",
    "Files" : "Datoteke",
    "Tags" : "Oznake",
    "Collaborative tags" : "Sodelovalne oznake",
    "Public" : "Javno",
    "Restricted" : "Omejeno",
    "Invisible" : "Nevidno",
    "Created tag" : "Oznaka je ustvarjena",
    "Failed to create tag" : "Ustvarjanje oznake je spodletelo",
    "Updated tag" : "Oznaka je posodobljena",
    "Failed to update tag" : "Posodabljanje oznake je spodletelo",
    "Deleted tag" : "Oznaka je izbrisana",
    "Failed to delete tag" : "Brisanje oznake je spodletelo",
    "Create or edit tags" : "Ustvarjanje ali urejanje oznak",
    "Search for a tag to edit" : "Iskanje oznak za urejanje",
    "Collaborative tags …" : "Sodelovalne oznake ...",
    "No tags to select" : "Ni izbranih oznak",
    "Tag name" : "Ime oznake",
    "Tag level" : "Raven oznake",
    "Create" : "Ustvari",
    "Update" : "Posodobi",
    "Delete" : "Izbriši",
    "Reset" : "Ponastavi",
    "Loading …" : "Poteka nalaganje …",
    "Manage tags" : "Upravljanje oznak",
    "Cancel" : "Prekliči",
    "Failed to load tags" : "Nalaganje oznak je spodletelo",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Sodelovalne oznake so na voljo vsem uporabnikom, omejitvene so uporabnikom vidne, a jih ni mogoče dodeliti, nevidne pa so namenjene sistemski rabi, uporabniki jih niti ne vidijo niti jih ne morejo dodeliti.",
    "Open in Files" : "Odpri v mapi",
    "No tags found" : "Ni najdenih oznak"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-31.0.12.tgz: nextcloud/apps/systemtags/l10n/sl.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Dodana je sistemska oznaka %1$s",
    "Added system tag {systemtag}" : "Dodana je sistemska oznaka {systemtag}",
    "Added system tag %1$s" : "Dodana je sistemska oznaka %1$s",
    "%1$s added system tag %2$s" : "Uporabnik %1$s doda sistemsko oznako %2$s",
    "{actor} added system tag {systemtag}" : "Uporabnik {actor} doda sistemsko oznako {systemtag}",
    "System tag %1$s removed by the system" : "Sistemska oznaka %1$s je odstranjena iz sistema",
    "Removed system tag {systemtag}" : "Odstranjena je sistemska oznaka {systemtag}",
    "Removed system tag %1$s" : "Odstranjena je sistemska oznaka %1$s",
    "%1$s removed system tag %2$s" : "%1$s odstrani sistemsko oznako %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstrani sistemsko oznako {systemtag}",
    "You created system tag %1$s" : "Ustvarite sistemsko oznako %1$s",
    "You created system tag {systemtag}" : "Ustvarite sistemsko oznako {systemtag}",
    "%1$s created system tag %2$s" : "Uporabnik %1$s je ustvaril sistemsko oznako %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ustvari sistemsko oznako {systemtag}",
    "You deleted system tag %1$s" : "Izbrišete sistemsko oznako %1$s",
    "You deleted system tag {systemtag}" : "Izbrišete sistemsko oznako {systemtag}",
    "%1$s deleted system tag %2$s" : "Uporabnik %1$s izbriše sistemsko oznako %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} izbriše sistemsko oznako {systemtag}",
    "You updated system tag %2$s to %1$s" : "Posodobili ste sistemsko oznako %2$s v %1$s.",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Posodobite sistemsko oznako {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s posodobi sistemsko oznako %3$s v %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} posodobi sistemsko oznako {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Sistem doda sistemsko oznako %2$s na datoteko %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Sistem doda sistemsko oznako {systemtag} na datoteko {file}",
    "You added system tag %2$s to %1$s" : "Datoteki %1$s dodate oznako %2$s.",
    "You added system tag {systemtag} to {file}" : "Datoteki {file} dodate sistemsko oznako {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s doda sistemsko oznako %3$s na datoteko %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} doda datoteki {file} sistemsko oznako {systemtag}",
    "System tag %2$s was removed from %1$s by the system" : "Sistem odstrani sistemsko oznako %2$s z datoteke %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Sistem odstrani sistemsko oznako {systemtag} z datoteke {file}",
    "You removed system tag %2$s from %1$s" : "Odstranili ste sistemsko oznako %2$s od %1$s",
    "You removed system tag {systemtag} from {file}" : "Odstranite sistemsko oznako {systemtag} z datoteke {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstrani sistemsko datoteko %3$s z datoteke %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstrani sistemsko oznako {systemtag} z datoteke {file}",
    "%s (restricted)" : "%s (omejeno)",
    "%s (invisible)" : "%s (nevidno)",
    "<strong>System tags</strong> for a file have been modified" : "Spremenjene so bile <strong>sistemske oznake</strong> datoteke",
    "Files" : "Datoteke",
    "Tags" : "Oznake",
    "Collaborative tags" : "Sodelovalne oznake",
    "Public" : "Javno",
    "Restricted" : "Omejeno",
    "Invisible" : "Nevidno",
    "Created tag" : "Oznaka je ustvarjena",
    "Failed to create tag" : "Ustvarjanje oznake je spodletelo",
    "Updated tag" : "Oznaka je posodobljena",
    "Failed to update tag" : "Posodabljanje oznake je spodletelo",
    "Deleted tag" : "Oznaka je izbrisana",
    "Failed to delete tag" : "Brisanje oznake je spodletelo",
    "Create or edit tags" : "Ustvarjanje ali urejanje oznak",
    "Search for a tag to edit" : "Iskanje oznak za urejanje",
    "No tags to select" : "Ni izbranih oznak",
    "Tag name" : "Ime oznake",
    "Tag level" : "Raven oznake",
    "Create" : "Ustvari",
    "Update" : "Posodobi",
    "Delete" : "Izbriši",
    "Reset" : "Ponastavi",
    "Manage tags" : "Upravljanje oznak",
    "Cancel" : "Prekliči",
    "Apply" : "Uveljavi",
    "Failed to load tags" : "Nalaganje oznak je spodletelo",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Sodelovalne oznake so na voljo vsem uporabnikom, omejitvene so uporabnikom vidne, a jih ni mogoče dodeliti, nevidne pa so namenjene sistemski rabi, uporabniki jih niti ne vidijo niti jih ne morejo dodeliti.",
    "Open in Files" : "Odpri v mapi",
    "No tags found" : "Ni najdenih oznak",
    "Collaborative tags …" : "Sodelovalne oznake ...",
    "Loading …" : "Poteka nalaganje …"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
